<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="escortTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchListEscort, changeState } from '@/api/warehouse/escort'
import ttable from '@/views/common/ztt-table.vue'
import TableForm from './escort-form'
import { mapGetters } from 'vuex'
export default {
  data() {
    return {
      clickDateArr: [],
      ajaxFun: fetchListEscort,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        column: [
          {
            minWidth: '140',
            prop: 'escortNo',
            label: '押运单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            minWidth: '120',
            prop: 'status',
            label: '押运单状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatStatus,
            optList: () => {
              return this.statusOptions
            }
          },
          {
            minWidth: '120',
            prop: 'orderNo',
            label: '订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'customerOrderNo',
            label: '客户订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'entityName',
            label: '工程名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'salesman',
            label: '业务员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '200',
            prop: 'requestDate',
            label: '要求到货日期',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDate
          },
          {
            minWidth: '120',
            prop: 'address',
            label: '交货地址',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'receiver',
            label: '联系人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'phone',
            label: '联系电话',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '200',
            prop: 'deliveryDate',
            label: '发货日期',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDate
          },
          {
            minWidth: '120',
            prop: 'carrier',
            label: '承运商',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          },
          {
            text: '完成',
            type: 'primary',
            fun: this.completeEscort
          },
          {
            text: '取消',
            type: 'primary',
            fun: this.cancelEscort
          }
        ],
        operator: null,
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      statusOptions: [
        {
          value: '01draft',
          label: '草稿',
          colorLabel: '<span style="color:red">草稿</span>'
        },
        {
          value: '02completed',
          label: '已完成',
          colorLabel: '已完成'
        }
      ]
    }
  },
  components: {
    ttable,
    TableForm
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      if (this.$refs.escortTable !== undefined) {
        this.$refs.escortTable.getDataList()
      }
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    formatDate(row, column, cellValue) {
      if (cellValue) {
        const dutyDateList = /\d{4}-\d{1,2}-\d{1,2}/g.exec(cellValue)
        if (dutyDateList && dutyDateList.length > 0) {
          return dutyDateList[0]
        }
      }
      return ''
    },
    formatStatus(row, column, cellValue) {
      this.statusOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.colorLabel
        }
      })
      return cellValue
    },
    validateRepeat() {
      var canClickFlag = true
      this.clickDateArr.push(new Date().getTime())
      if (this.clickDateArr.length > 1) {
        if (
          this.clickDateArr[this.clickDateArr.length - 1] -
            this.clickDateArr[this.clickDateArr.length - 2] <
          2000
        ) {
          // 小于2秒则认为重复提交
          canClickFlag = false
        }
      }
      if (!canClickFlag) {
      }
    },

    // 完成
    completeEscort() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        for (let i = 0; i < this.multipleSelection.length; i++) {
          if (this.multipleSelection[i].status === '02completed') {
            this.$message.warning('请选择草稿的押运单')
            return
          }
        }

        var canClickFlag = true
        this.clickDateArr.push(new Date().getTime())
        if (this.clickDateArr.length > 1) {
          if (
            this.clickDateArr[this.clickDateArr.length - 1] -
              this.clickDateArr[this.clickDateArr.length - 2] <
            2000
          ) {
            // 小于2秒则认为重复提交
            canClickFlag = false
          }
        }
        if (!canClickFlag) {
          return
        }

        changeState(this.multipleSelection, 'COMPLETE').then((response) => {
          this.$message.success('完成成功')
          this.getData()
        })
      } else {
        this.$message.warning('请选择需要完成的押运单')
      }
    },
    // 取消
    cancelEscort() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        for (let i = 0; i < this.multipleSelection.length; i++) {
          if (this.multipleSelection[i].status === '01draft') {
            this.$message.warning('请选择已完成的押运单')
            return
          }
        }

        var canClickFlag = true
        this.clickDateArr.push(new Date().getTime())
        if (this.clickDateArr.length > 1) {
          if (
            this.clickDateArr[this.clickDateArr.length - 1] -
              this.clickDateArr[this.clickDateArr.length - 2] <
            2000
          ) {
            // 小于2秒则认为重复提交
            canClickFlag = false
          }
        }
        if (!canClickFlag) {
          return
        }

        changeState(this.multipleSelection, 'CANCEL').then((response) => {
          this.$message.success('取消成功')
          this.getData()
        })
      } else {
        this.$message.warning('请选择需要取消的押运单')
      }
    }
  }
}
</script>
